#/bin/bash
# -*- coding: utf-8 -*-

# @author = Danny Rehl
# @date = 26.12.2012
# @version = 1.1
# @email = rehl@cl.uni-heidelberg.de

# REQUIRED: fully configured 'msmtp'

textmessage=$1
addressfile=$2

# test if tmp file exists, if yes, make backup
[ -f headersection.serm ] && mv headersection.serm headersection.serm.bak

################################################
####### GET HEADER INFORMATION FROM USER #######
################################################

### create header-section
headersection=()

# Subject
echo -n "Betreff [Subject]: "
read headersubject

# From (Name)
echo -n "Absender Name: "
read headerfromname
# From (E-Mail)
echo -n "Absender E-Mail Adresse [From]: "
read headerfromemail

# CC
echo -n "CC: "
read headercc

# BCC
echo -n "BCC: "
read headerbcc

# Sender
echo -n "Technischer Absender [Sender]: "
read headersender

# Reply-To
echo -n "Antwort an (optional) [Reply-To]: "
read headerreplyto

# Return-Path
echo -n "Unzustellbarkeitsinfo an (optional) [Return-Path]: "
read headerreturnpath

################################################
####### SAVE HEADER INFORMATION TO ARRAY #######
################################################

##### order recommened by RFC 2616, Chapter 4.2
# 1. Return-Path
[[ $headerreturnpath != "" ]] && headersection+=("Return-Path: $headerreturnpath")
# 2. Date (computed when mail is sent)
# 3. From
[[ $headerfromname == "" ]] && [[ $headerfromemail != "" ]] && headerfrom="$headerfromemail"
[[ $headerfromname != "" ]] && [[ $headerfromemail == "" ]] && headerfrom="$headerfromname"
[[ $headerfromname != "" ]] && [[ $headerfromemail != "" ]] && headerfrom="$headerfromname <$headerfromemail>"
[[ $headerfrom != "" ]] && headersection+=("From: $headerfrom")
# 4. Sender
[[ $headersender != "" ]] && [[ $headersender != $headerfromemail ]] && headersection+=("Sender: $headersender")
# 5. Reply-To
[[ $headerreplyto != "" ]] && headersection+=("Reply-To: $headerreplyto")
# 6. CC
[[ $headercc != "" ]] && headersection+=("CC: $headercc")
# 7. BCC
[[ $headerbcc != "" ]] && headersection+=("BCC: $headerbcc")
# 8. Subject
[[ $headersubject == "" ]] && headersection+=("Subject: kein Betreff") || headersection+=("Subject: $headersubject")
# 9. Encoding
headersection+=("MIME-Version: 1.0")
headersection+=("Content-Type: text/plain; charset=UTF-8")
headersection+=("Content-Transfer-Encoding: 8bit")

# use comma as seperator in csv file
IFS=","

# read items in addressfile
# 1.: Firstname
# 2.: E-Mail address
# 3.: Gender
while read firstname receiver gender; do
	# add specific language dependent character to salutation string
	# masculinum = with 'r', femininum = empty
	[[ $gender == "m" ]] && addstring="r" || addstring=""
	# print stdout msg
	echo "Sending E-Mail to $firstname <$receiver>"
	# get time stamp
	datearray=("Date: `date -R`")
	# compute header file with right order (RFC 2616)
	rm headersection.serm 2> /dev/null
	if [[ `echo ${headersection[0]} | grep "^Return-Path"` == "" ]]
	then
		echo "${datearray[@]}" >> headersection.serm
		for el in "${headersection[@]}"
		do
			echo "$el" >> headersection.serm
		done
	else
		echo "${headersection[0]}" >> headersection.serm
		echo "${datearray[@]}" >> headersection.serm
		for el in "${headersection[@]:1}"
		do
			echo "$el" >> headersection.serm
		done
	fi
	# seperating: <LF> between header and body
	echo >> headersection.serm

	# replace #GEND and #FIRSTNAME template in textmessage according to
	# addressbook (csv-file) and send email via msmtp
	cat headersection.serm $textmessage | sed s/"#GEND"/"$addstring"/g | sed s/"#FIRSTNAME"/"$firstname"/g | msmtp $receiver
	# uncomment this line for debug
	cat headersection.serm $textmessage | sed s/"#GEND"/"$addstring"/g | sed s/"#FIRSTNAME"/"$firstname"/g >> $textmessage.send; echo "" >> $textmessage.send
done < $addressfile

rm headersection.serm 2> /dev/null
